@@ -15,6 +15,7 @@ from slixmpp.stanza import StreamFeatures, Presence, Iq
 from slixmpp.xmlstream import register_stanza_plugin, JID
 from slixmpp.xmlstream.handler import Callback
 from slixmpp.xmlstream.matcher import StanzaPath
+from slixmpp.util import MemoryCache
 from slixmpp import asyncio
 from slixmpp.exceptions import XMPPError, IqError, IqTimeout
 from slixmpp.plugins import BasePlugin
@@ -27,7 +28,7 @@ log = logging.getLogger(__name__)
 class XEP_0115(BasePlugin):
 
     """
-    XEP-0115: Entity Capabalities
+    XEP-0115: Entity Capabilities
     """
 
     name = 'xep_0115'
@@ -37,7 +38,8 @@ class XEP_0115(BasePlugin):
     default_config = {
         'hash': 'sha-1',
         'caps_node': None,
-        'broadcast': True
+        'broadcast': True,
+        'cache': None,
     }
 
     def plugin_init(self):
@@ -48,6 +50,9 @@ class XEP_0115(BasePlugin):
         if self.caps_node is None:
             self.caps_node = 'http://slixmpp.com/ver/%s' % __version__
 
+        if self.cache is None:
+            self.cache = MemoryCache()
+
         register_stanza_plugin(Presence, stanza.Capabilities)
         register_stanza_plugin(StreamFeatures, stanza.Capabilities)
 
@@ -132,8 +137,7 @@ class XEP_0115(BasePlugin):
 
         self.xmpp.event('entity_caps', p)
 
-    @asyncio.coroutine
-    def _process_caps(self, pres):
+    async def _process_caps(self, pres):
         if not pres['caps']['hash']:
             log.debug("Received unsupported legacy caps: %s, %s, %s",
                     pres['caps']['node'],
@@ -164,7 +168,7 @@ class XEP_0115(BasePlugin):
         log.debug("New caps verification string: %s", ver)
         try:
             node = '%s#%s' % (pres['caps']['node'], ver)
-            caps = yield from self.xmpp['xep_0030'].get_info(pres['from'], node,
+            caps = await self.xmpp['xep_0030'].get_info(pres['from'], node,
                                                              coroutine=True)
 
             if isinstance(caps, Iq):
@@ -199,8 +203,8 @@ class XEP_0115(BasePlugin):
                 log.debug("Non form extension found, ignoring for caps")
                 caps.xml.remove(stanza.xml)
                 continue
-            if 'FORM_TYPE' in stanza['fields']:
-                f_type = tuple(stanza['fields']['FORM_TYPE']['value'])
+            if 'FORM_TYPE' in stanza.get_fields():
+                f_type = tuple(stanza.get_fields()['FORM_TYPE']['value'])
                 form_types.append(f_type)
                 deduped_form_types.add(f_type)
                 if len(form_types) != len(deduped_form_types):
@@ -214,7 +218,7 @@ class XEP_0115(BasePlugin):
                         log.debug("Extra FORM_TYPE data, invalid for caps")
                         return False
 
-                if stanza['fields']['FORM_TYPE']['type'] != 'hidden':
+                if stanza.get_fields()['FORM_TYPE']['type'] != 'hidden':
                     log.debug("Field FORM_TYPE type not 'hidden', " + \
                               "ignoring form for caps")
                     caps.xml.remove(stanza.xml)
@@ -253,7 +257,7 @@ class XEP_0115(BasePlugin):
 
         for stanza in info['substanzas']:
             if isinstance(stanza, self.xmpp['xep_0004'].stanza.Form):
-                if 'FORM_TYPE' in stanza['fields']:
+                if 'FORM_TYPE' in stanza.get_fields():
                     f_type = stanza['values']['FORM_TYPE']
                     if len(f_type):
                         f_type = f_type[0]
@@ -265,11 +269,11 @@ class XEP_0115(BasePlugin):
         for f_type in sorted_forms:
             for form in form_types[f_type]:
                 S += '%s<' % f_type
-                fields = sorted(form['fields'].keys())
+                fields = sorted(form.get_fields().keys())
                 fields.remove('FORM_TYPE')
                 for field in fields:
                     S += '%s<' % field
-                    vals = form['fields'][field].get_value(convert=False)
+                    vals = form.get_fields()[field].get_value(convert=False)
                     if vals is None:
                         S += '<'
                     else:
@@ -280,10 +284,9 @@ class XEP_0115(BasePlugin):
         binary = hash(S.encode('utf8')).digest()
         return base64.b64encode(binary).decode('utf-8')
 
-    @asyncio.coroutine
-    def update_caps(self, jid=None, node=None, preserve=False):
+    async def update_caps(self, jid=None, node=None, preserve=False):
         try:
-            info = yield from self.xmpp['xep_0030'].get_info(jid, node, local=True)
+            info = await self.xmpp['xep_0030'].get_info(jid, node, local=True)
             if isinstance(info, Iq):
                 info = info['disco_info']
             ver = self.generate_verstring(info, self.hash)
