@@ -147,8 +147,8 @@ def multifactory(stanza, plugin_attrib):
     Multi.is_extension = True
     Multi.plugin_attrib = plugin_attrib
     Multi._multistanza = stanza
-    Multi.interfaces = set([plugin_attrib])
-    Multi.lang_interfaces = set([plugin_attrib])
+    Multi.interfaces = {plugin_attrib}
+    Multi.lang_interfaces = {plugin_attrib}
     setattr(Multi, "get_%s" % plugin_attrib, get_multi)
     setattr(Multi, "set_%s" % plugin_attrib, set_multi)
     setattr(Multi, "del_%s" % plugin_attrib, del_multi)
@@ -212,8 +212,8 @@ class ElementBase(object):
         >>> class Message(ElementBase):
         ...     name = "message"
         ...     namespace = "jabber:client"
-        ...     interfaces = set(('to', 'from', 'type', 'body'))
-        ...     sub_interfaces = set(('body',))
+        ...     interfaces = {'to', 'from', 'type', 'body'}
+        ...     sub_interfaces = {'body'}
 
     The resulting Message stanza's contents may be accessed as so::
 
@@ -239,7 +239,7 @@ class ElementBase(object):
         >>> class MessagePlugin(ElementBase):
         ...     name = "custom_plugin"
         ...     namespace = "custom"
-        ...     interfaces = set(('useful_thing', 'custom'))
+        ...     interfaces = {'useful_thing', 'custom'}
         ...     plugin_attrib = "custom"
 
     The plugin stanza class must be associated with its intended
@@ -311,7 +311,7 @@ class ElementBase(object):
     #: manipulating the underlying XML object. This set may be augmented
     #: with the :attr:`plugin_attrib` value of any registered
     #: stanza plugins.
-    interfaces = set(('type', 'to', 'from', 'id', 'payload'))
+    interfaces = {'type', 'to', 'from', 'id', 'payload'}
 
     #: A subset of :attr:`interfaces` which maps interfaces to direct
     #: subelements of the underlying XML object. Using this set, the text
@@ -379,20 +379,6 @@ class ElementBase(object):
     #: .. versionadded:: 1.0-Beta5
     plugin_iterables = set()
 
-    #: A deprecated version of :attr:`plugin_iterables` that remains
-    #: for backward compatibility. It required a parent stanza to
-    #: know beforehand what stanza classes would be iterable::
-    #:
-    #:     class DiscoItem(ElementBase):
-    #:         ...
-    #:
-    #:     class DiscoInfo(ElementBase):
-    #:         subitem = (DiscoItem, )
-    #:         ...
-    #:
-    #: .. deprecated:: 1.0-Beta5
-    subitem = set()
-
     #: The default XML namespace: ``http://www.w3.org/XML/1998/namespace``.
     xml_ns = XML_NS
 
@@ -426,10 +412,6 @@ class ElementBase(object):
             else:
                 self.parent = parent
 
-        if self.subitem is not None:
-            for sub in self.subitem:
-                self.plugin_iterables.add(sub)
-
         if self.setup(xml):
             # If we generated our own XML, then everything is ready.
             return
@@ -637,7 +619,7 @@ class ElementBase(object):
                         plugin.values = value
         return self
 
-    def __getitem__(self, attrib):
+    def __getitem__(self, full_attrib):
         """Return the value of a stanza interface using dict-like syntax.
 
         Example::
@@ -664,24 +646,16 @@ class ElementBase(object):
             8. The plugin named ``'foo'``
             9. An empty string.
 
-        :param string attrib: The name of the requested stanza interface.
+        :param string full_attrib: The name of the requested stanza interface.
         """
-        full_attrib = attrib
-        attrib_lang = ('%s|' % attrib).split('|')
-        attrib = attrib_lang[0]
-        lang = attrib_lang[1] or None
+        attrib, lang, *_ = ('%s|' % full_attrib).split('|')
 
-        kwargs = {}
-        if lang and attrib in self.lang_interfaces:
-            kwargs['lang'] = lang
-
-        kwargs = OrderedDict(kwargs)
+        kwargs = {'lang': lang} if lang and attrib in self.lang_interfaces else {}
 
         if attrib == 'substanzas':
             return self.iterables
         elif attrib in self.interfaces or attrib == 'lang':
             get_method = "get_%s" % attrib.lower()
-            get_method2 = "get%s" % attrib.title()
 
             if self.plugin_overrides:
                 name = self.plugin_overrides.get(get_method, None)
@@ -694,8 +668,6 @@ class ElementBase(object):
 
             if hasattr(self, get_method):
                 return getattr(self, get_method)(**kwargs)
-            elif hasattr(self, get_method2):
-                return getattr(self, get_method2)(**kwargs)
             else:
                 if attrib in self.sub_interfaces:
                     return self._get_sub_text(attrib, lang=lang)
@@ -758,7 +730,6 @@ class ElementBase(object):
         if attrib in self.interfaces or attrib == 'lang':
             if value is not None:
                 set_method = "set_%s" % attrib.lower()
-                set_method2 = "set%s" % attrib.title()
 
                 if self.plugin_overrides:
                     name = self.plugin_overrides.get(set_method, None)
@@ -771,8 +742,6 @@ class ElementBase(object):
 
                 if hasattr(self, set_method):
                     getattr(self, set_method)(value, **kwargs)
-                elif hasattr(self, set_method2):
-                    getattr(self, set_method2)(value, **kwargs)
                 else:
                     if attrib in self.sub_interfaces:
                         if lang == '*':
@@ -845,7 +814,6 @@ class ElementBase(object):
 
         if attrib in self.interfaces or attrib == 'lang':
             del_method = "del_%s" % attrib.lower()
-            del_method2 = "del%s" % attrib.title()
 
             if self.plugin_overrides:
                 name = self.plugin_overrides.get(del_method, None)
@@ -858,8 +826,6 @@ class ElementBase(object):
 
             if hasattr(self, del_method):
                 getattr(self, del_method)(**kwargs)
-            elif hasattr(self, del_method2):
-                getattr(self, del_method2)(**kwargs)
             else:
                 if attrib in self.sub_interfaces:
                     return self._del_sub(attrib, lang=lang)
@@ -941,11 +907,17 @@ class ElementBase(object):
         stanzas = self.xml.findall(name)
         if not stanzas:
             return default
+        result = None
         for stanza in stanzas:
             if stanza.attrib.get('{%s}lang' % XML_NS, default_lang) == lang:
                 if stanza.text is None:
                     return default
-                return stanza.text
+                result = stanza.text
+                break
+            if stanza.text:
+                result = stanza.text
+        if result is not None:
+            return result
         return default
 
     def _get_all_sub_text(self, name, default='', lang=None):
@@ -1148,36 +1120,6 @@ class ElementBase(object):
         # Everything matched.
         return True
 
-    def find(self, xpath):
-        """Find an XML object in this stanza given an XPath expression.
-
-        Exposes ElementTree interface for backwards compatibility.
-
-        .. note::
-
-            Matching on attribute values is not supported in Python 2.6
-            or Python 3.1
-
-        :param string xpath: An XPath expression matching a single
-                             desired element.
-        """
-        return self.xml.find(xpath)
-
-    def findall(self, xpath):
-        """Find multiple XML objects in this stanza given an XPath expression.
-
-        Exposes ElementTree interface for backwards compatibility.
-
-        .. note::
-
-            Matching on attribute values is not supported in Python 2.6
-            or Python 3.1.
-
-        :param string xpath: An XPath expression matching multiple
-                             desired elements.
-        """
-        return self.xml.findall(xpath)
-
     def get(self, key, default=None):
         """Return the value of a stanza interface.
 
@@ -1305,20 +1247,6 @@ class ElementBase(object):
         if attr in self.xml.attrib:
             del self.xml.attrib[attr]
 
-    @property
-    def attrib(self):
-        """Return the stanza object itself.
-
-        Older implementations of stanza objects used XML objects directly,
-        requiring the use of ``.attrib`` to access attribute values.
-
-        Use of the dictionary syntax with the stanza object itself for
-        accessing stanza interfaces is preferred.
-
-        .. deprecated:: 1.0
-        """
-        return self
-
     def _fix_ns(self, xpath, split=False, propagate_ns=True):
         return fix_ns(xpath, split=split,
                              propagate_ns=propagate_ns,
@@ -1457,10 +1385,10 @@ class StanzaBase(ElementBase):
     #: There is a small set of attributes which apply to all XMPP stanzas:
     #: the stanza type, the to and from JIDs, the stanza ID, and, especially
     #: in the case of an Iq stanza, a payload.
-    interfaces = set(('type', 'to', 'from', 'id', 'payload'))
+    interfaces = {'type', 'to', 'from', 'id', 'payload'}
 
     #: A basic set of allowed values for the ``'type'`` interface.
-    types = set(('get', 'set', 'error', None, 'unavailable', 'normal', 'chat'))
+    types = {'get', 'set', 'error', None, 'unavailable', 'normal', 'chat'}
 
     def __init__(self, stream=None, xml=None, stype=None,
                  sto=None, sfrom=None, sid=None, parent=None):
